"""
sys - для безопасного выхода в случае исключения
click - для запусука модуля через cmd
numpy - для работы с массивами
selection_sort - обработка данных
"""
import sys
import click
import numpy as np
import selection_sort


@click.command()
@click.argument('f_and_list', nargs=-1)
def main(f_and_list):
    """
    Главная функция(?)
    """
    f_and_list = np.array(f_and_list)
    if not f_and_list.size:
        print('Вы ничего не ввели')
        sys.exit(0)
    answer = f_and_list[0]
    check_list = np.array(f_and_list)[1:]
    if not check_list.size:
        print('Вы ввели всего 1 число, нужно минимум 2')
        sys.exit(0)
    try:
        answer = int(answer)
    except ValueError:
        print('Вы не ввели число в начале')
        sys.exit(0)
    try:
        check_list = check_list.astype(int)
    except ValueError:
        print('Вы не ввели числа через пробел')
        sys.exit(0)
    if answer == 1:
        result = selection_sort.selection_sort_1(check_list)
        print(*result)
    if answer == 2:
        result = selection_sort.selection_sort_2(check_list)
        print(*result)


if __name__ == '__main__':
    main()



"""
А.О. Блинов,КИ21-16/1Б, вариант 3
Программа реализующая выборочную сортировку
"""


def check_list(base_list):
    """
    Функция для проверки списка на корректность данных

    >>> check_list()
    TypeError
    >>> check_list(1,'a',2)
    TypeError
    """
    if not base_list:
        raise TypeError('Введён некорректный список')
    for i in base_list:
        if not str(i).isdigit():
            if not str(i)[1:].isdigit():
                raise TypeError('Введён некорректный список')


def selection_sort_1(base_list):
    """
    Выборочная сортировка по возрастанию

    >>> selection_sort_1([5, 2, 4, 3])
    [2, 3, 4, 5]
    >>> selection_sort_1([7, 6, 4, 2])
    [2, 4, 6, 7]
    """
    check_list(base_list)
    for i in range(len(base_list) - 1):
        minimal = i
        for j in range(i + 1, len(base_list)):
            if base_list[j] < base_list[minimal]:
                minimal = j
        base_list[i], base_list[minimal] = base_list[minimal], base_list[i]
    return base_list


def selection_sort_2(base_list):
    """
    Выборочная сортировка по убыванию

    >>> selection_sort_2([5, 2, 4, 3])
    [5, 4, 3, 2]
    >>> selection_sort_2([7, 6, 4, 2])
    [7, 6, 4, 2]
    """
    check_list(base_list)
    for i in range(len(base_list) - 1):
        maximum = i
        for j in range(i + 1, len(base_list)):
            if base_list[j] > base_list[maximum]:
                maximum = j
        base_list[i], base_list[maximum] = base_list[maximum], base_list[i]
    return base_list


if __name__ == '__main__':
    import doctest

    doctest.testmod()



from setuptools import setup, find_packages

setup(
    name='selection_sort',
    version='0.0.3',
    packages=find_packages(),
    author='Jiro1703',
    author_email='absurd4657@mail.ru',
    install_requires=[
        'click'
    ],
    entry_points={
        'console_scripts': [
            'selection_sort=selection_sort:main'
            'selection_sort.py=selection_sort:main'
        ]
    }
)
